import request from '@/utils/dsRequest'

export function QueryShelf(data) {
  return request({
    url: '/Shelf/QueryShelfPager',
    method: 'post',
    data
  })
}

export function CreateShelf(data) {
  return request({
    url: '/Shelf/CreateShelf',
    method: 'post',
    data
  })
}
export function GetShelf(data) {
  return request({
    url: '/Shelf/GetShelf',
    method: 'post',
    data
  })
}

export function UpdateShelf(data) {
  return request({
    url: '/Shelf/UpdateShelf',
    method: 'post',
    data
  })
}

export function DeleteShelf(data) {
  return request({
    url: '/Shelf/DeleteShelf',
    method: 'post',
    data
  })
}

export function DisableShelf(data) {
  return request({
    url: '/Shelf/DisableShelf',
    method: 'post',
    data
  })
}

export function EnableShelf(data) {
  return request({
    url: '/Shelf/EnableShelf',
    method: 'post',
    data
  })
}

export function LoadShelInfo(data) {
  return request({
    url: '/Shelf/LoadShelInfo',
    method: 'post',
    data
  })
}
